@@ -16,6 +16,7 @@
 #' `missing` : if TRUE, missing data is considered; FALSE only uses complete cases.
 #' 
 #' `digits` : significant digits to use.
+#' @seealso Additional prewritten summary functions for binary data: \link[tangram.pipe]{binary_pct}, \link[tangram.pipe]{binary_count}, \link[tangram.pipe]{binary_jama}
 #' @import dplyr
 #' @keywords tangram.pipe
 #' @export
@@ -54,8 +55,9 @@ binary_default <- function(dt, ...){
     
   out <- matrix(paste0(sprintf(rnd, prop), " (", ct, ")"), nrow=nrow(prop), dimnames=dimnames(prop)) %>%
     as.data.frame()
-  out <- cbind(rownames(out), out)
+  out <- cbind(dimnames(prop)[[1]], out)
   rownames(out) <- NULL
+  out[is.na(out)] <- "NA."
   row1 <- c(paste(rowlabel), rep("", ncol(out)-1))
   out <- rbind(row1, out)
 
@@ -68,6 +70,7 @@ binary_default <- function(dt, ...){
   out <- cbind(out[,1], Measure="", out[,(2:ncol(out))])
   if (compact == TRUE){
     out$Measure[2] <- "Col. Prop. (N)"
+    out[2,1] <- paste0(out[1,1], ": ", out[2,1])
     out <- out[-1,]
   } else {
     out$Measure[1] <- "Col. Prop. (N)"
