@@ -1,6 +1,6 @@
 #' Binary Row
 #'
-#' Adds in a binary row to the table.
+#' Adds in a binary row to a `tangram.pipe` table.
 #' @param list_obj the name of the `tbl_start` object previously initialized.
 #' @param row_var the name of the variable to be used in the rows.
 #' @param col_var the variable to be used in the table columns. Default is from initialized `tbl_start` object.
@@ -15,6 +15,9 @@
 #' @param digits significant digits to use.
 #' @param indent number of spaces to indent category names.
 #' @return A list with the binary row's table information added as a new element to `list_obj`.
+#' @seealso Possible summary functions for binary data:\link[tangram.pipe]{binary_default}, \link[tangram.pipe]{binary_pct}, \link[tangram.pipe]{binary_count}, \link[tangram.pipe]{binary_jama}
+#' @seealso Other related row-building functions: \link[tangram.pipe]{num_row}, \link[tangram.pipe]{cat_row}, \link[tangram.pipe]{n_row}, \link[tangram.pipe]{empty_row}
+#' @seealso Starting a `tangram.pipe` table: \link[tangram.pipe]{tbl_start}
 #' @import dplyr
 #' @keywords tangram.pipe
 #' @examples 
@@ -60,14 +63,14 @@ binary_row <- function(
     col_var <- list_obj[["col_var"]]
     num_col <- list_obj[['num_col']]
   } else {
-    if (class(newdata) == 'logical'){
+    if (inherits(newdata, 'logical')){
       num_col <- list_obj[['data']][col_var] %>%
         filter(!is.na(list_obj[['data']][col_var])) %>%
         unique() %>%
         nrow()
     }
   }
-  if (class(newdata) == 'logical'){
+  if (inherits(newdata, 'logical')){
     data <- list_obj[['data']][,c(row_var, col_var)]
   } else {
     data <- newdata[,c(row_var, col_var)]
@@ -120,7 +123,7 @@ binary_row <- function(
     binary_out <- binary_out[,-ncol(binary_out)]
   }
 
-  if (class(comparison) == "function" & num_col > 1){
+  if (inherits(comparison, "function") & num_col > 1){
     comp <- comparison(data, num_col, reference, digits)
     for (i in 1:ncol(comp)){
       binary_out$compare <- ""
