@@ -1,6 +1,6 @@
 #' Categorical Row
 #'
-#' Adds in a categorical row to the table.
+#' Adds in a categorical row to a `tangram.pipe` table.
 #' @param list_obj the name of the `tbl_start` object previously initialized.
 #' @param row_var the name of the variable to be used in the rows.
 #' @param col_var the variable to be used in the table columns. Default is from initialized `tbl_start` object.
@@ -11,8 +11,13 @@
 #' @param overall logical: if TRUE, an overall column is included.
 #' @param comparison the name of the comparison test to use, if different from that initialized in `tbl_start`.
 #' @param digits significant digits to use.
+#' @param ordering If `ascending`, will sort by overall ascending order; if `descending`, will sort by overall descending order. Default is no row sorting.
+#' @param sortcol Column to sort row on. Requires `ordering` to be `ascending` or `descending`. By default, will sort based on overall statistics.
 #' @param indent number of spaces to indent category names.
 #' @return A list with the categorical row's table information added as a new element to `list_obj`.
+#' @seealso Possible summary functions for categorical data:\link[tangram.pipe]{cat_default}, \link[tangram.pipe]{cat_pct}, \link[tangram.pipe]{cat_count}, \link[tangram.pipe]{cat_jama}
+#' @seealso Other related row-building functions: \link[tangram.pipe]{num_row}, \link[tangram.pipe]{binary_row}, \link[tangram.pipe]{n_row}, \link[tangram.pipe]{empty_row}
+#' @seealso Starting a `tangram.pipe` table: \link[tangram.pipe]{tbl_start}
 #' @import dplyr
 #' @keywords tangram.pipe
 #' @examples 
@@ -32,6 +37,8 @@ cat_row <- function(
   , overall=NULL
   , comparison=NULL  #Null or function
   , digits=2
+  , ordering="none"
+  , sortcol=NULL
   , indent=5
 ){
   # Determine if row parameters override initialized defaults
@@ -56,14 +63,14 @@ cat_row <- function(
     col_var <- list_obj[["col_var"]]
     num_col <- list_obj[['num_col']]
   } else {
-    if (class(newdata) == 'logical'){
+    if (inherits(newdata, 'logical')){
       num_col <- list_obj[['data']][col_var] %>%
         filter(!is.na(list_obj[['data']][col_var])) %>%
         unique() %>%
         nrow()
     }
   }
-  if (class(newdata) == 'logical'){
+  if (inherits(newdata, 'logical')){
     data <- list_obj[['data']][,c(row_var, col_var)] #list_obj %>% le('data') %>% select(row_var, col_var)
   } else {
     data <- newdata[,c(row_var, col_var)]
@@ -99,12 +106,17 @@ cat_row <- function(
   #Default summary function will take % (N)
 
   #Calculations
-  cat_out <- summary(data, rowlabel = rowlabel, missing = missing, digits = digits)
+  cat_out <- summary(data, 
+                     rowlabel = rowlabel, 
+                     missing = missing, 
+                     digits = digits, 
+                     ordering = ordering, 
+                     sortcol = sortcol)
   if (overall == FALSE){
     cat_out <- cat_out[,-ncol(cat_out)]
   }
 
-  if (class(comparison) == "function" & num_col > 1){
+  if (inherits(comparison, "function") & num_col > 1){
     comp <- comparison(data, digits)
     for (i in 1:ncol(comp)){
       cat_out$compare <- ""
